# pyqt-ani-abstractbutton
PyQt QAbstractButton for <a href="https://github.com/yjg30737/pyqt-ani-button.git">pyqt-ani-button</a> and <a href="https://github.com/yjg30737/pyqt-ani-toolbutton.git">pyqt-ani-toolbutton</a>'s style and feature

## Requirements
* PyQt5 >= 5.8

## Setup
`python -m pip install pyqt-ani-abstractbutton`
